#
# spec file for package libmirage
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libmirage
%define lname   libmirage11
%define pname	3_2
Summary:        A CD-ROM image access library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Version:        3.2.2
Release:        lp150.2.6.1
URL:            http://cdemu.sf.net/about/libmirage/

#Git-Clone:     git://git.code.sf.net/p/cdemu/code
Source:         https://downloads.sf.net/cdemu/%name-%version.tar.bz2
Patch1:         0001-libMirage-CSO-filter-validate-part-size.patch
Patch2:         0002-libMirage-CSO-filter-replaced-a-g_assert-with-error-.patch
Patch3:         CVE-2019-15757.patch
BuildRequires:  cmake >= 2.8.5
BuildRequires:  intltool >= 0.21
BuildRequires:  pkg-config >= 0.16
BuildRequires:  pkgconfig(bzip2) >= 1.0.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.38
BuildRequires:  pkgconfig(glib-2.0) >= 2.38
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.38
BuildRequires:  pkgconfig(gobject-2.0) >= 2.38
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(gtk-doc) >= 1.4
BuildRequires:  pkgconfig(liblzma) >= 5.0.0
BuildRequires:  pkgconfig(samplerate) >= 0.1.0
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(sndfile) >= 1.0.0
BuildRequires:  pkgconfig(zlib) >= 1.2.4
Recommends:     %name-lang

%description
A CD-ROM image access library part of the cdemu suite.

libmirage provides uniform access to the data stored in different
image formats by creating a representation of disc stored in image
file.

%package lang
Summary:        Translations for libmirage
Group:          System/Localization
Provides:       %name-lang-all = %version
Supplements:    packageand(bundle-lang-other:%lname)
BuildArch:      noarch

%description lang
Provides translations for the "%name" package.

%package -n %lname
Summary:        A CD-ROM image access library
# Technically Suggests:, but pretty useless without
Group:          System/Libraries
Requires:       libmirage-%pname >= %version

%description -n %lname
A CD-ROM image access library part of the cdemu suite.

libmirage provides uniform access to the data stored in different
image formats by creating a representation of disc stored in image
file.

%package %pname
Summary:        CD-ROM image format plugins for libmirage
Group:          System/Libraries
Recommends:     libmirage-data

%description %pname
A CD-ROM image access library part of the cdemu suite.

libmirage provides uniform access to the data stored in different
image formats by creating a representation of disc stored in image
file.

This package provides the image format plugins for libmirage.

%package devel
Summary:        Development files for libmirage, a CD-ROM image access library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       glib2-devel

%description devel
A CD-ROM image access library part of the cdemu suite.

libmirage provides uniform access to the data stored in different
image formats by creating a representation of disc stored in image
file.

This package contains files needed to develop with libmirage.

%package data
Summary:        MIME type definitions and documentation for libmirage
Group:          Development/Libraries/C and C++
Requires(post): shared-mime-info
Requires(postun): shared-mime-info
BuildArch:      noarch

%description data
libmirage provides uniform access to the data stored in different
image formats by creating a representation of disc stored in image
file.

This package contains the MIME type definitions and documentation.

%package -n typelib-1_0-libmirage-%pname
Summary:        Introspection bindings for the libmirage CD-ROM image access library
Group:          System/Libraries

%description -n typelib-1_0-libmirage-%pname
libmirage provides uniform access to the data stored in different
image formats by creating a representation of disc stored in image
file.

This package provides the GObject Introspection bindings for libmirage.

%prep
%autosetup -p2

%build
%cmake -DCMAKE_MODULE_LINKER_FLAGS=""
make %{?_smp_mflags}

%install
%cmake_install
%find_lang %name

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%post data
%mime_database_post

%postun data
%mime_database_postun

%files -n %lname
%_libdir/libmirage.so.11*

%files %pname
%_libdir/libmirage-3*/

%files data
%_datadir/gtk-doc/
%_datadir/mime/packages/*

%files devel
%_includedir/libmirage-3*/
%_libdir/libmirage.so
%_libdir/pkgconfig/libmirage.pc
%_datadir/gir-1.0

%files lang -f %name.lang

%files -n typelib-1_0-libmirage-%pname
%_libdir/girepository-1.0

%changelog
* Tue Sep  3 2019 Jan Engelhardt <jengelh@inai.de>
- Add CVE-2019-15757.patch [boo#1148728]
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Drop SLE11 recipes from specfile, the build is disabled anyway.
- Add 0001-libMirage-CSO-filter-validate-part-size.patch,
  0002-libMirage-CSO-filter-replaced-a-g_assert-with-error-.patch
  [boo#1148087, CVE-2019-15540]
* Mon Jul  1 2019 Aaron Stern <ukbeast89@ptotonmail.com>
- Update to new upstream release 3.2.2
  * ISO parser: fixed ISO9660/UDF pattern search for sector
    sizes 2332 and 2336.
  * ISO parser: added support for Nintendo GameCube and Wii
    ISO images.
  * Extended medium type guess to distinguish between DVD and
    BluRay images based on length.
  * Removed fabrication of disc structures from the library
    (moved to CDEmu daemon).
  * MDS parser: cleanup of disc structure parsing, fixed the
    incorrectly set structure sizes.
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 3.1.0
  * Avoid using g_assert_nonnull() to keep compatibility with
    glib <= 2.40.
  * Adjusted bundled MIME types to prevent false positives.
  * Added infrastructure for localization support.
  * Slovenian and Russian translations.
  * Improved compile-time checks of arguments passed to debug
    message functions.
  * Explicitly specify minimum required zlib version (1.2.4).
  * Fixed acquisition of underlying streams in DMG ans ISZ filters.
- Drop 01_g_assert_nonnull.diff,
  libmirage-3.0.5-glib-2.28-workaround.patch
  (integrated upstream)
* Thu Apr  6 2017 zenitur@ya.ru
- Fix SLES 11 build. We're also need Glib 2.28 instead of 2.22.5.
  Most desktop and workstation users are turn on Packman
  repository, so they're have Glib 2.28 installed from there.
- Added 01_g_assert_nonnull.diff patch taken from Cdemu PPA.
- Add libmirage-3.0.5-glib-2.28-workaround.patch
- Add glib2-devel as a required for the -devel package. That fixes
  some rpmbuild warning.
* Mon Feb  6 2017 jengelh@inai.de
- Update to new upstream release 3.0.5
  * Removed a spurious stream reference increment when creating
    text streams.
  * CUE parser: fixed the flags regex
  * Text-based parsers: added an assert to verify that all regexes
    have compiled properly.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 3.0.4:
  * CUE, CCD, TOC, XCDRoast parsers: Fix a crash due to invalid
    read attempts on uninitialised regex match info structure.
  * MDS, MDX parser: Fix a memory leak.
  * CIF parser: Fix signature matching.
  * CIF parser: Improve pretty-print of some values.
  * CIF parser: Fix track length calculation.
  * CMake: Replace whitespaces in custom target names with "-"
    signs (silence CMP0037 warnings on CMake 3.2.2 and newer).
- Add missing MIME compilation.
- Use %%cmake macro.
* Tue Nov 25 2014 jengelh@inai.de
- Update to new upstream release 3.0.3
  * fixed an out-of-bounds array access when initializing CRC-32
  table data in mirage_helper_init_crc32_lut()
* Thu Oct  2 2014 jengelh@inai.de
- Update to new upstream release 3.0.2
  * TOC writer: fixed object (session, track, fragment) leak.
  Fixes problems with no data being written to files in cases when
  a virtual image is written, its target files removed and then
  burned again.
* Sat Sep  6 2014 jengelh@inai.de
- Update to new upstream release 3.0.1
  * added missing installation rules for GBI and XMD MIME types
* Sun Jul 13 2014 sor.alexei@meowr.ru
- Update to new upstream release 3.0.0
  * The file access and filter stream layer in libMirage were
  revised to allow implementation of filters for both reading and
  writing, and an infrastructure for implementing image writers
  was added, along with reference implementations for ISO and TOC
  writers.
* Sun Nov 24 2013 jengelh@inai.de
- Update to new upstream release 2.1.1
  * sector's EDC is now computed using fast slice-by-8 CRC32 algorithm
  * added function for ISRC validation to be used by image parsers
- Remove 0001-libMirage-proper-versioning-of-the-introspection-typ.patch
  (merged upstream)
* Sun Jun  9 2013 jengelh@inai.de
- Update to new upstream release 2.1.0
  * This release adds a MacBinary/NDIF file filter, a new resource
  fork parser for DMG, samplerate conversion for the SndFile filter,
  non-blocking I/O, and dynamic device addition/removal.
- Remove patches (merged upstream):
  0001-libMirage-CMake-fix-SOVERSION-which-should-be-set-to.patch,
  0001-libMirage-READCD-Parser-readcd-from-cdrtools-appears.patch,
  0001-libMirage-READCD-Parser-when-verifying-the-file-don-.patch,
  0001-libMirage-SNDFILE-filter-instead-of-a-single-frame-c.patch
- Add (cherry-picked fixes):
  0001-libMirage-proper-versioning-of-the-introspection-typ.patch
* Tue Mar 12 2013 jengelh@inai.de
- Add 0001-libMirage-SNDFILE-filter-instead-of-a-single-frame-c.patch
  to resolve excess CPU usage during CDDA readout
  (bnc#809181, bnc#809862)
* Sun Feb 24 2013 jengelh@inai.de
- Add 0001-libMirage-READCD-Parser-when-verifying-the-file-don-.patch
  0001-libMirage-READCD-Parser-readcd-from-cdrtools-appears.patch
  to make images created by readcd(1) usable again
  (bugurl: http://sf.net/p/cdemu/feature-requests/21/)
* Sat Jan  5 2013 jengelh@inai.de
- Add 0001-libMirage-CMake-fix-SOVERSION-which-should-be-set-to.patch
* Sat Dec 22 2012 jengelh@inai.de
- Update to new upstream release 2.0.0 (up from 1.5.0)
  * Added ISZ, CSO and DMG file filters
  * Converted DAA parser to a file filter and added support for the
  related GBI format
  * Converted audio fragment to a file filter
  * Added file filter machinery and converted existing code to use it
  * Image analyzer displays disc structures
  * Added support for gobject introspection
  * Added support for GZIP and XZ compressed images
  * Added support for ECM'ed files
  * Improved CIF parser
  * Partial support for (one track) MDX images
  * Improved GVFS support
* Mon May 21 2012 jengelh@inai.de
- Initial package for build.opensuse.org
